#
# spec file for package tintii
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           tintii
Version:        2.10.0
Release:        4.39
Summary:        Selective Colour Photo Filter
License:        GPL-2.0
Group:          Productivity/Graphics/Bitmap Editors
Url:            http://www.indii.org/software/tintii
Source0:        http://www.indii.org/files/tint/releases/%{name}-%{version}.tar.gz
Source1:        http://www.indii.org/images/%{name}_128.png
BuildRequires:  ImageMagick
BuildRequires:  bc
%if 0%{?suse_version} > 1325
BuildRequires:  libboost_headers-devel
%else
BuildRequires:  boost-devel
%endif
BuildRequires:  gcc-c++
BuildRequires:  update-desktop-files
BuildRequires:  wxWidgets-devel >= 3
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
tintii takes full colour photos and processes them into black and white
with some select regions highlighted in colour. The technique is known
as colour popping or selective colouring.

%prep
%setup -q

%build
%configure --disable-assert
make %{?_smp_mflags}

%install
%make_install
# Create desktop file.
cat > %{name}.desktop << EOF
[Desktop Entry]
Name=tintii
GenericName=Selective Colour Photo Filter
GenericName[ru]=Избирательный фильтр цветов фотографий
Type=Application
Exec=tintii %f
Icon=tintii
Categories=Graphics;Photography;
Comment=Selective processing colour photos into black and white
Comment[ru]=Избирательное преобразование цветных фотографий в чёрно-белые
StartupNotify=true
Terminal=false
MimeType=image/gif;image/jpeg;image/png;image/tiff;image/x-bmp;image/x-portable-pixmap;image/x-pcx;image/x-targa;image/x-xpm;
EOF
install -Dm 0644 %{name}.desktop \
    %{buildroot}%{_datadir}/applications/%{name}.desktop

# Install icons of various sizes.
install -Dm 0644 %{SOURCE1} \
    %{buildroot}%{_datadir}/icons/hicolor/128x128/apps/%{name}.png
for size in 96x96 64x64 48x48 32x32 22x22 16x16 ; do
    install -dm 0755 \
        %{buildroot}%{_datadir}/icons/hicolor/${size}/apps
    convert -strip -resize ${size} %{SOURCE1} \
        %{buildroot}%{_datadir}/icons/hicolor/${size}/apps/%{name}.png
done
%suse_update_desktop_file %{name}

%post
%desktop_database_post
%icon_theme_cache_post

%postun
%desktop_database_postun
%icon_theme_cache_postun

%files
%defattr(-,root,root,-)
%doc COPYING README
%{_bindir}/%{name}
%{_datadir}/%{name}/
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/*/*/%{name}.*

%changelog
* Mon Feb  6 2017 jengelh@inai.de
- Make description neutral
* Thu Feb  2 2017 adam.majer@suse.de
- use individual libboost-*-devel packages instead of boost-devel
* Thu Jun  2 2016 lazy.kent@opensuse.org
- Fix "find requires" (remove %%wx_requires).
* Sun Dec 13 2015 lazy.kent@opensuse.org
- Fix build dependencies. BuildRequires: wxWidgets-3_0-devel >= 3
  for all openSUSE versions.
* Thu Dec 10 2015 p.drouand@gmail.com
- Update to version 2.10
  * Bugfixes release
- Build with wxWidgets-devel >= 3.0 for openSUSE >= 13.2
- Add bc BuildRequires
* Mon Jul  7 2014 lazy.kent@opensuse.org
- Update to 2.9.0.
  * Improvements to behaviour of lightness sliders, now influenced
    by saturation decay.
  * Performance improvements.
- Changes in 2.8.2.
  * Fixed crash bug for particular image sizes.
- Changes in 2.8.1.
  * Retina display support.
* Sat Oct 19 2013 lazy.kent@opensuse.org
- Correct the source URL because of OBS download service issue.
* Sun Oct  6 2013 lazy.kent@opensuse.org
- Update to 2.8.0.
  * Added 16 and 32 bits per channel support to plugin.
  * Window size and position now preserved between launches.
  * Tweaked default settings, particularly hardness.
* Sun Mar 18 2012 lazy.kent@opensuse.org
- Update to 2.6.1.
  * Fixed zoom-fit function.
  * Fixed GCC 4.6 compile errors.
* Tue Mar 13 2012 lazy.kent@opensuse.org
- Update to 2.6.0.
  * Centred image in preview pane and added textured background.
  * Changed lightness sliders to apply multiplicative rather than
    additive adjustments.
  * Added info bar for help messages.
  * Separated file types in open and save dialogs.
  * New application icon.
- Use defines for wxWidgets.
- Added mimetypes.
- Install icons of various sizes to icons/hicolor (build requires
  ImageMagick).
- Added desktop_database_post/un and icon_theme_cache_post/un
  macros.
- Clean up spec.
* Sat Oct 22 2011 pascal.bleser@opensuse.org
- update to 2.5.3: no user-visible changes
- changes from 2.5.2:
  * the layout of interface components is now more flexible
  * a list of recently open files has been added to the menu bar
  * a crash when a file of unsupported type is opened has been fixed
- changes from 2.4.0:
  * sliders for adjusting the hue, saturation, and lightness of each detected
    color have been added
  * a new hardness post-processing option for working with gradients has been
    added
  * the interface has been freshened and full online help is now included
* Sun May 29 2011 lazy.kent@opensuse.org
- removed licenses dependencies
- use full URL in source tag
* Sat Jan 22 2011 lazy.kent@opensuse.org
- build requires wxWidgets-devel for openSUSE 11.4
* Sat May  8 2010 lazy.kent.suse@gmail.com
- moved desktop menu entry to Photography
* Fri Apr  2 2010 lazy.kent.suse@gmail.com
- update to 2.2.3
* Tue Jan 26 2010 pascal.bleser@opensuse.org
- moved to multimedia:photo
- update to 2.2.2
- added license symlink
* Sat Dec 12 2009 lazy.kent.suse@gmail.com
- initial package created
